==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DuplicateSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DuplicateSpecFluent<A extends DuplicateSpecFluent<A>> extends BaseFluent<A>{
  public DuplicateSpecFluent() {
  }
  
  public DuplicateSpecFluent(DuplicateSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String duplicate;
  
  protected void copyInstance(DuplicateSpec instance) {
    instance = (instance != null ? instance : new DuplicateSpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withDuplicate(instance.getDuplicate());
        this.withCorrelation(instance.getCorrelation());
        this.withDuplicate(instance.getDuplicate());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getDuplicate() {
    return this.duplicate;
  }
  
  public A withDuplicate(String duplicate) {
    this.duplicate=duplicate; return (A) this;
  }
  
  public boolean hasDuplicate() {
    return this.duplicate != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DuplicateSpecFluent that = (DuplicateSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(duplicate, that.duplicate)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  duplicate,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (duplicate != null) { sb.append("duplicate:"); sb.append(duplicate); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/DuplicateSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DuplicateSpecFluent<A extends DuplicateSpecFluent<A>> extends BaseFluent<A>{
  public DuplicateSpecFluent() {
  }
  
  public DuplicateSpecFluent(DuplicateSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String duplicate;
  
  protected void copyInstance(DuplicateSpec instance) {
    instance = (instance != null ? instance : new DuplicateSpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withDuplicate(instance.getDuplicate());
          this.withCorrelation(instance.getCorrelation());
          this.withDuplicate(instance.getDuplicate());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getDuplicate() {
    return this.duplicate;
  }
  
  public A withDuplicate(String duplicate) {
    this.duplicate = duplicate;
    return (A) this;
  }
  
  public boolean hasDuplicate() {
    return this.duplicate != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DuplicateSpecFluent that = (DuplicateSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(duplicate, that.duplicate)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  duplicate,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (duplicate != null) { sb.append("duplicate:"); sb.append(duplicate); }
    sb.append("}");
    return sb.toString();
  }
  

}
